@@ -4,7 +4,7 @@ import string
 import sys
 from itertools import chain, product
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __all__ = ['braceexpand', 'alphabet', 'UnbalancedBracesError']
 
@@ -13,10 +13,9 @@ class UnbalancedBracesError(ValueError): pass
 PY3 = sys.version_info[0] >= 3
 
 if PY3:
-    alphabet = string.ascii_uppercase + string.ascii_lowercase
     xrange = range
-else:
-    alphabet = string.uppercase + string.lowercase
+
+alphabet = string.ascii_uppercase + string.ascii_lowercase
 
 int_range_re = re.compile(r'^(\d+)\.\.(\d+)(?:\.\.-?(\d+))?$')
 char_range_re = re.compile(r'^([A-Za-z])\.\.([A-Za-z])(?:\.\.-?(\d+))?$')
@@ -172,7 +171,10 @@ def parse_sequence(seq, escape):
 
 
 def make_int_range(start, end, step=None):
-    padding = max([len(start), len(end)]) if '0' in (start[0], end[0]) else 0
+    if any([s[0] == '0' for s in (start, end) if s != '0']):
+        padding = max(len(start), len(end))
+    else:
+        padding = 0
     step = int(step) if step else 1
     start = int(start)
     end = int(end)
